# Changelog

### [0.0.7](https://www.github.com/lsmo-epfl/EQeq/compare/v0.0.6...v0.0.7) (2021-06-25)


### Bug Fixes

* include the header files ([8363bf7](https://www.github.com/lsmo-epfl/EQeq/commit/8363bf727baa5dc3259f88b59be9ac9acdb00139))

### [0.0.6](https://www.github.com/lsmo-epfl/EQeq/compare/v0.0.5...v0.0.6) (2021-06-24)


### Bug Fixes

* update manifest ([81a3168](https://www.github.com/lsmo-epfl/EQeq/commit/81a3168b36cc0e80ffc0e61c85abb8c4519e9d0e))

### [0.0.5](https://www.github.com/lsmo-epfl/EQeq/compare/v0.0.4...v0.0.5) (2021-06-24)


### Bug Fixes

* bump version number ([65418b0](https://www.github.com/lsmo-epfl/EQeq/commit/65418b063deca7fbb96758233c06378a1ad8eed7))

### [0.0.4](https://www.github.com/lsmo-epfl/EQeq/compare/v0.0.3...v0.0.4) (2021-06-24)


### Bug Fixes

* long description type ([8f22fe6](https://www.github.com/lsmo-epfl/EQeq/commit/8f22fe6183ae6b7368b6cefa16cf894182773688))

### [0.0.3](https://www.github.com/lsmo-epfl/EQeq/compare/v0.0.2...v0.0.3) (2021-06-24)


### Bug Fixes

* bump version number ([9d8ca9a](https://www.github.com/lsmo-epfl/EQeq/commit/9d8ca9ae0ba29614a0562bcacfaca0672844a46d))

### [0.0.2](https://www.github.com/lsmo-epfl/EQeq/compare/v0.0.1...v0.0.2) (2021-06-24)


### Bug Fixes

* add long description type ([50d76e9](https://www.github.com/lsmo-epfl/EQeq/commit/50d76e9d78c05506221114ab54664add937fcfe2))

### [0.0.1](https://www.github.com/lsmo-epfl/EQeq/compare/v1.1.0...v0.0.1) (2021-06-24)


### Features

* allow write to file ([cbee797](https://www.github.com/lsmo-epfl/EQeq/commit/cbee79768771e65af127bf0e1a6334a6a1783864))
* build extension with pybind11 ([65868b7](https://www.github.com/lsmo-epfl/EQeq/commit/65868b74188912b5b64bf1cdf08ea6f525c8a0fc))
* build extension with pybind11 ([56947a6](https://www.github.com/lsmo-epfl/EQeq/commit/56947a61978b3a87e2e4c133b15c6ac57ce233ad))
* using toml to specify build dependency ([9bca8fb](https://www.github.com/lsmo-epfl/EQeq/commit/9bca8fb350f070db8f8e9919e46a9b5f61eed716))
